import { LoadingManager, Material, MaterialCreator, TextureLoader, Scene } from 'three';
export declare class VRMLLoader {
    constructor(manager?: LoadingManager);
    manager: LoadingManager;
    materials: Material[];
    path: string;
    resourcePath: string;
    isRecordingPoints: boolean;
    isRecordingFaces: boolean;
    points: any[];
    indexes: any[];
    isRecordingAngles: boolean;
    isRecordingColors: boolean;
    angles: any[];
    colors: any[];
    recordingFieldname: string | null;
    crossOrigin: string;
    lines: string[];
    defines: {};
    index: any[];
    float_pattern: RegExp;
    float2_pattern: RegExp;
    float3_pattern: RegExp;
    textureLoader: TextureLoader;
    scene: Scene;
    load(url: string, onLoad: (scene: Scene) => void, onProgress?: (event: ProgressEvent) => void, onError?: (event: ErrorEvent) => void): void;
    setPath(value: string): void;
    parse(data: any, path: string): Scene;
    setResuorcePath(value: string): void;
    setCrossOrigin(value: string): void;
    setMaterials(materials: MaterialCreator): void;
    _createParserState(): any;
    /**
     * Vertically paints the faces interpolating between the
     * specified colors at the specified angels. This is used for the Background
     * node, but could be applied to other nodes with multiple faces as well.
     *
     * When used with the Background node, default is directionIsDown is true if
     * interpolating the skyColor down from the Zenith. When interpolationg up from
     * the Nadir i.e. interpolating the groundColor, the directionIsDown is false.
     *
     * The first angle is never specified, it is the Zenith (0 rad). Angles are specified
     * in radians. The geometry is thought a sphere, but could be anything. The color interpolation
     * is linear along the Y axis in any case.
     *
     * You must specify one more color than you have angles at the beginning of the colors array.
     * This is the color of the Zenith (the top of the shape).
     *
     * @param geometry geometry
     * @param radius radius
     * @param angles angles
     * @param colors colors
     * @param boolean topDown Whether to work top down or bottom up.
     */
    private parseV2;
    private paintFaces;
    private parseProperty;
    private getTree;
    parseNode(data: any, parent: any): void;
    private triangulateIndexArray;
}
