/** * Imports ***/
import ModelsBase from './models.base';
import { Vector3 } from 'three';
/**
 * Frame object.
 *
 * @ module models/frame
 */
export default class ModelsFrame extends ModelsBase {
    /**
     * Constructor
     */
    _sopInstanceUID: any;
    _url: any;
    _stackID: number;
    _invert: boolean;
    _frameTime: any;
    _ultrasoundRegions: any[];
    _rows: number;
    _columns: number;
    _dimensionIndexValues: any[];
    _imagePosition: any;
    _imageOrientation: any;
    _rightHanded: boolean;
    _sliceThickness: number;
    _spacingBetweenSlices: any;
    _pixelPaddingValue: any;
    _pixelRepresentation: number;
    _pixelType: number;
    _pixelSpacing: any;
    _pixelAspectRatio: any;
    _pixelData: any;
    _instanceNumber: any;
    _windowCenter: any;
    _windowWidth: any;
    _rescaleSlope: any;
    _rescaleIntercept: any;
    _bitsAllocated: number;
    _numberOfChannels: number;
    _minMax: any;
    _dist: any;
    _index: number;
    _referencedSegmentNumber: number;
    constructor();
    /**
     * Validate the frame.
     *
     * @ param {*} model
     *
     * @ return {*}
     */
    validate(model: any): boolean;
    /**
     * Merge current frame with provided frame.
     *
     * Frames can be merged (i.e. are identical) if following are equals:
     *  - dimensionIndexValues
     *  - imageOrientation
     *  - imagePosition
     *  - instanceNumber
     *  - sopInstanceUID
     *
     * @ param {*} frame
     *
     * @ return {boolean} True if frames could be merge. False if not.
     */
    merge(frame: any): boolean;
    /**
     * Generate X, y and Z cosines from image orientation
     * Returns default orientation if _imageOrientation was invalid.
     *
     * @ returns {array} Array[3] containing cosinesX, Y and Z.
     */
    cosines(): Vector3[];
    /**
     * Get x/y spacing of a frame.
     *
     * @ return {*}
     */
    spacingXY(): number[];
    /**
     * Get data value
     *
     * @ param {*} column
     * @ param {*} row
     * @ return {*}
     */
    getPixelData(column: any, row: any): any;
    /**
     * Set data value
     *
     * @ param {*} column
     * @ param {*} row
     * @ param {*} value
     * @ return {*}
     */
    setPixelData(column: any, row: any, value: any): void;
    /**
     * Get frame preview as data:URL
     *
     * @ return {String}
     */
    getImageDataUrl(): string;
    /**
     * Convert frame.pixelData to canvas.context.imageData.data
     *
     * @ return {Uint8Array}
     */
    _frameToCanvas(): Uint8Array;
    /**
     * Convert pixel value to 8 bit (canvas.context.imageData.data: maximum 8 bit per each of RGBA value)
     *
     * @ param {Number} value  Pixel value
     * @ param {Object} params {invert, min, mix, padding, range}
     *
     * @ return {Number}
     */
    _pixelTo8Bit(value: any, params: any): number;
    /**
     * Compare 2 arrays.
     *
     * 2 null arrays return true.
     * Do no perform strict type checking.
     *
     * @ param {*} reference
     * @ param {*} target
     *
     * @ return {boolean} True if arrays are identicals. False if not.
     */
    _compareArrays(reference: any, target: any): boolean;
    frameTime: any;
    ultrasoundRegions: any[];
    rows: number;
    columns: number;
    spacingBetweenSlices: any;
    sliceThickness: number;
    imagePosition: any;
    imageOrientation: any;
    windowWidth: any;
    windowCenter: any;
    rescaleSlope: any;
    rescaleIntercept: any;
    bitsAllocated: number;
    dist: any;
    pixelSpacing: any;
    pixelAspectRatio: any;
    minMax: any;
    dimensionIndexValues: any[];
    instanceNumber: any;
    pixelData: any;
    sopInstanceUID: any;
    pixelPaddingValue: any;
    pixelRepresentation: number;
    pixelType: number;
    url: any;
    referencedSegmentNumber: number;
    rightHanded: boolean;
    index: number;
    invert: boolean;
    numberOfChannels: number;
}
