import { Observable } from 'rxjs';
export declare type Reducer<T> = (state: T, index: number) => T;
export declare type MetaReducer<T, R> = (s: Store<T>) => Store<R>;
export interface Store<T> {
    state$: Observable<T>;
    dispatch(action: Reducer<T>): Observable<never>;
    complete(): void;
    currentState(): T;
}
export declare function store<T>(init: T): Store<T>;
export interface WithId {
    id: string;
}
export declare type Item<T> = T & WithId;
export declare type EqOp<T> = (a: T) => (b: T) => boolean;
export declare const eqId: EqOp<WithId>;
export declare class StoreByArray<E extends WithId, T extends E> implements Store<T[]> {
    private equalTo;
    /**
     * E is minimal type to apply to equalTo
     * T is type of object stored
     * e.g. if T = { name: string, id: string }, E could be { id: string }
     */
    readonly state$: Observable<T[]>;
    constructor(equalTo?: EqOp<E>);
    private s;
    dispatch(action: Reducer<T[]>): Observable<never>;
    currentState(): T[];
    complete(): void;
    get$(key: E): Observable<T>;
    filter$(fn: (x: T) => boolean): Observable<T[]>;
    setState(state: T[]): Observable<never>;
    insert(item: T): Observable<never>;
    remove(item: T): Observable<never>;
    update(...values: T[]): Observable<never>;
    clear(): Observable<never>;
}
